import React$1, { HTMLAttributes, CSSProperties, ReactNode } from 'react';

interface Props$8 {
    children: React$1.ReactNode;
}

declare const Provider: React$1.FC<Props$8>;

interface Options {
    id?: string;
    date?: number;
    position?: 'top' | 'top-left' | 'top-right' | 'bottom' | 'bottom-left' | 'bottom-right';
    duration?: number;
    speed?: number;
    title?: React$1.ReactNode;
    description?: React$1.ReactNode;
    type?: 'success' | 'info' | 'warning' | 'error';
    color?: string;
    background?: string;
    isClosable?: boolean;
}

interface ManagerOptions {
    toasts: Options[];
    setToasts: React$1.Dispatch<React$1.SetStateAction<Options[]>>;
    close: string;
    setClose: React$1.Dispatch<React$1.SetStateAction<string>>;
    options: Options;
}
declare class ToastManager {
    private config;
    constructor(config: ManagerOptions);
    close(): ToastManager;
    setTitle(title: string): ToastManager;
    setDescription(desc: string): ToastManager;
    setType(type: 'success' | 'info' | 'warning' | 'error'): ToastManager;
    setClosable(isClosable?: boolean): ToastManager;
}

interface Props$7 {
    children: React$1.ReactNode;
}

interface IToastContext {
    toast: (options: Options) => ToastManager;
    toasts: Options[];
    setToasts: React$1.Dispatch<React$1.SetStateAction<Options[]>>;
    close: string;
    setClose: React$1.Dispatch<React$1.SetStateAction<string>>;
}
declare const useToast: () => IToastContext;
declare const ToastProvider: ({ children }: Props$7) => JSX.Element;

declare type TailwindColors = 'slate' | 'gray' | 'zinc' | 'neutral' | 'stone' | 'red' | 'orange' | 'amber' | 'yellow' | 'lime' | 'green' | 'emerald' | 'teal' | 'cyan' | 'sky' | 'blue' | 'indigo' | 'violet' | 'purple' | 'fuchsia' | 'pink' | 'rose';

interface BaseProps {
    theme?: TailwindColors;
    className?: HTMLAttributes<HTMLAnchorElement>['className'];
    style?: CSSProperties;
}

interface Props$6 extends BaseProps {
    children: React$1.ReactNode[] | React$1.ReactNode;
    indicatorClass?: string;
    tabClass?: string;
    activeTabClass?: string;
}

declare function Tab({ children }: Props$6): JSX.Element;

declare function Tabs({ children }: Props$6): JSX.Element;

declare function TabsGroup({ indicatorClass, tabClass, activeTabClass, children }: Props$6): JSX.Element;

declare function Panel({ children }: Props$6): JSX.Element;

declare function Panels({ children }: Props$6): JSX.Element;

interface Props$5 {
    children: any;
    nav?: any;
    footer?: any;
    finishComponent?: any;
    onEnd?: (data: any) => void;
    onPrev?: (data: any) => void;
    onNext?: (data: any) => void;
}

declare function Wizard({ nav: Navbar, footer: Footer, finishComponent: FinishComponent, onEnd, onNext, onPrev, children }: Props$5): JSX.Element;

declare function Step({ children }: Props$5): JSX.Element;

interface Props$4 {
    className?: string;
    style?: React$1.CSSProperties;
    theme?: TailwindColors;
    invalid?: boolean;
    disabled?: boolean;
    readOnly?: boolean;
    required?: boolean;
    placeholder?: string;
    invalidText?: string;
    leftAddon?: React$1.ReactNode;
    rightAddon?: React$1.ReactNode;
    label?: string;
}

declare function Input({ className, theme, invalid, invalidText, disabled, leftAddon, rightAddon, ...props }: React$1.PropsWithChildren<Props$4> & React$1.InputHTMLAttributes<HTMLInputElement>): JSX.Element;

declare function Checkbox({ className, theme, label, ...props }: React$1.PropsWithChildren<Props$4> & React$1.InputHTMLAttributes<HTMLInputElement>): JSX.Element;

interface Props$3 {
    bg?: string;
    background?: string;
    hl?: string;
    highlight?: string;
    className?: HTMLAttributes<HTMLAnchorElement>['className'];
}

declare const Skeleton: React.FC<Props$3>;

interface Props$2 {
    size?: 'xs' | 'sm' | 'md' | 'lg' | 'xl';
    color?: string;
}

declare const Spinner: React.FC<Props$2>;

interface Props$1 {
    children: ReactNode;
    isOpen: boolean;
    onClose: () => void;
    animation?: 'fade' | 'scale' | 'reverseScale';
    backdrop?: string | boolean;
    blur?: string | boolean;
    closeOnOverlayClick?: boolean;
}

declare const Modal: React$1.FC<Props$1>;

interface Props {
    children?: ReactNode;
    isOpen: boolean;
    onClose: () => void;
    className?: string;
    align?: 'left' | 'right' | 'top' | 'bottom';
}

declare function Left({ children, isOpen, onClose, className, align }: Props): JSX.Element | null;

declare function Right({ children, isOpen, onClose, className, align }: Props): JSX.Element | null;

declare function Top({ children, isOpen, onClose, className, align }: Props): JSX.Element | null;

declare function Bottom({ children, isOpen, onClose, className, align }: Props): JSX.Element | null;

declare const classNames: (classList: string) => string;

export { Checkbox, Bottom as DrawerBottom, Left as DrawerLeft, Right as DrawerRight, Top as DrawerTop, Input, Modal, Panel, Panels, Provider, Skeleton, Spinner, Step, Tab, Tabs, TabsGroup, ToastProvider, Wizard, classNames, useToast };
